@@ -115,10 +115,11 @@ def calc_contrast_loss(features,assignment_orig,device,args):
         top_assignment = assignment_orig[:,ph].topk(pos_batch*10,0)[1]   
         
         # Feature distance to top-k
-        feat_dist = torch.matmul(features[top_assignment], features[top_assignment].T).sum(1)
+        feat_dist = torch.matmul(features[top_assignment], features[top_assignment].T)
         
         # Select most similar patches
-        top_elem = (feat_dist.topk(pos_batch,0)[1])
+        prototype = (feat_dist.sum(0).topk(1,0)[1])
+        top_elem = (feat_dist[prototype][0,:].topk(pos_batch,0)[1])
         
         # Positive loss - patches with similar features to the top-k patches should have the same assignment
         positives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][top_elem].T)/temp)) 
@@ -133,11 +134,12 @@ def calc_contrast_loss(features,assignment_orig,device,args):
         
 
         # Patches with highest confidence assignment          
-        bottom_val = feat_dist.topk(pos_batch*9,0,largest=False)[1]
+        bottom_val = feat_dist[prototype][0,:].topk(pos_batch*9,0,largest=False)[1]
         sel_vals_neg = torch.randint(0, pos_batch*9, (pos_batch,))
         # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
-        negatives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][bottom_val[sel_vals_neg]].T)/temp))        
-        loss += -torch.log(positives/negatives).mean()
+        # negatives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][bottom_val[sel_vals_neg]].T)/temp))    
+        # loss += torch.log(negatives).mean()*temp    
+        loss += -torch.log(positives).mean()*temp
         # print('Positives: '+str((torch.log(positives).mean()*temp).item()*100)[:5]+' feat_pos: '+str(feat_dist[top_elem[0]].item())[:6]+'   -   Negative: '+str((torch.log(negatives).mean()*temp).item()*100)[:5]+' feat_neg: '+str(feat_dist[bottom_val[0]].item())[:6])
         
     return loss/assignment_orig.shape[1]
