@@ -40,12 +40,12 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 3 if debug=='Index' else hp.choice('epochs',[6,15,30,400]) if debug=='Object' else 400
+        args['epochs'] = 3 if debug=='Index' else hp.choice('epochs',[6,15,30,2000]) if debug=='Object' else 2000
         args['lr_decay_factor'] = 0.25# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 11000#max(int(args['epochs']/2),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
         args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 12, 25]) if debug=='Object' else 12
-        args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.000001
+        args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
 
         # General
         args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
@@ -67,8 +67,8 @@ def parameters(path, debug):
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
         
         # Losses
-        args['ContrastACC_Pheno'] = 1000000# if debug=='Index' else hp.choice("ContrastACC_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.01
-        args['ContrastACC_Neigh'] = 1000000# if debug=='Index' else hp.choice("ContrastACC_Neigh", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 1
+        args['ContrastACC_Pheno'] = 1000# if debug=='Index' else hp.choice("ContrastACC_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.01
+        args['ContrastACC_Neigh'] = 1000# if debug=='Index' else hp.choice("ContrastACC_Neigh", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 1
         args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("ContrastACC_Area", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001
         args['PatchEntropy_Pheno'] = 0#1 if debug=='Index' else hp.choice("PatchEntropy_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.1   
         args['PatchEntropy_Neigh'] = 0#1 if debug=='Index' else hp.choice("PatchEntropy_Neigh", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.1
@@ -77,7 +77,7 @@ def parameters(path, debug):
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = False
         args['Perc_high_conf_patches'] = 0.0001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. A low values generates rare populations.                                  
-        args['TSNE_Perc_Pat'] = 0.00001 # Percentage of patients to use to generate the tsne.     
+        args['TSNE_Perc_Pat'] = 0.5 # Percentage of patients to use to generate the tsne.     
 
 
     elif 'Melanoma_ProgressionvsBaseline' in path:            
@@ -326,15 +326,15 @@ def parameters(path, debug):
         args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
         args['n_hops_neighborhoods'] = 2 
         args['Phenotype_Learning'] = True  
-        args['Neighborhood_Learning'] = True
-        args['Area_Learning'] = True
+        args['Neighborhood_Learning'] = False
+        args['Area_Learning'] = False
         args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
         args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
                 
         # Losses
-        args['ContrastACC_Pheno'] = 1000#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
-        args['ContrastACC_Neigh'] = 1000#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Pheno'] = 1# 4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 0 # 4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
         args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001 
         args['Perc_high_conf_patches'] = 0.001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. Low values generate rare populations.
         args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
@@ -375,12 +375,12 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 10# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['epochs'] = 2# if debug else hp.quniform('epochs', 5, 25, 1)
         args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
-        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 32]) if debug=='Object' else 32
-        args['lr'] = 1 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.1
+        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 64]) if debug=='Object' else 64
+        args['lr'] = 1 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
 
         # General
         args['training_MODE'] = 'CrossValidation' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
@@ -391,7 +391,7 @@ def parameters(path, debug):
 
         # Neural Network
         args['N_Phenotypes'] = 6#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
-        args['N_Neighborhoods'] = 8#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Neighborhoods'] = 6#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
         args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
         args['n_hops_neighborhoods'] = 3
         args['Phenotype_Learning'] = True  
@@ -534,6 +534,7 @@ def parameters(path, debug):
         args['ContrastACC_Pheno'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
         args['ContrastACC_Neigh'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
         args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['Perc_high_conf_patches'] = 0.001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. Low values generate rare populations.
         args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
         args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
         args['PatchEntropy_Area'] = 0#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
@@ -542,6 +543,74 @@ def parameters(path, debug):
         args['Bio_save_Orig_im'] = False
         args['TSNE_Perc_Pat'] = 0.5 # Percentage of patients used to calculate TSNE. 1 is 100% of patients
 
+
+    elif 'AKOYA_Arlene_Tonsil' in path:            
+        
+        # Patch contrastive learning parameters
+        args['PCL_CNN_Architecture']='resnet50' # or resnet18
+        args['PCL_N_Workers']=10 # Number of data loading workers 
+        args['PCL_Epochs']=100 # Number of total epoch to run
+        args['PCL_N_Crops_per_Image']=20 # Number of crops chosen per image
+        args['PCL_Patch_Size']=40 # Size of patches in pixels
+        args['PCL_Stride']=0 # Size of stride between consecutive patches
+        args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
+        args['PCL_Z_Score']= True # Whether to apply z score per channel/marker
+        args['PCL_Batch_Size']= 50 # Number of images per iteration
+        args['PCL_Weight_Decay']= 1e-4 # Weight Decay
+        args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate
+        args['PCL_Temperature']= 0.07 # Softmax temperature                
+        args['PCL_eliminate_Black_Background'] = False
+        args['PCL_eliminate_White_Background'] = False
+        args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
+        args['PCL_Color_perturbation_Augmentation'] = False # Color augmentation for H&E tissue staining.
+
+        # Label you want to infer with respect the images.
+        args['experiment_Label'] = ['Unsupervised'] 
+
+        # Architecture Search parameters
+        args['num_samples_architecture_search'] = 1500  
+
+        # Optimization Parameters
+        args['NaroNet_n_workers'] = 1
+        args['epochs'] = 1000
+        args['lr_decay_factor'] = 0.1
+        args['lr_decay_step_size'] = 10000
+        args['weight_decay'] = 0
+        args['batch_size'] = 128
+        args['lr'] = 0.1 
+
+        # General
+        args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
+        args['folds'] = 1
+        args['device'] = 'cuda:0'
+        args['Batch_Normalization'] = True
+        args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
+
+        # Neural Network
+        args['N_Phenotypes'] = 72#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
+        args['N_Neighborhoods'] = 36#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Areas'] = 6#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
+        args['n_hops_neighborhoods'] = 1
+        args['Phenotype_Learning'] = True  
+        args['Neighborhood_Learning'] = True
+        args['Area_Learning'] = True
+        args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
+        args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
+        args['1Patch1Cluster'] = False
+                
+        # Losses
+        args['ContrastACC_Pheno'] = 1#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 1#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
+        args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
+        args['PatchEntropy_Area'] = 1#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
+        
+        # Bioinsights parameters
+        args['Bio_save_Orig_im'] = True
+        args['TSNE_Perc_Pat'] = 1 # Percentage of patients used to calculate TSNE. 1 is 100% of patients
+
     else:
         
         # Patch contrastive learning parameters
